@@ -672,6 +672,7 @@ create_button (widget_info *w, int should_dump, int should_fill) {
 	label = gtk_label_new (w->str);
 	gtk_misc_set_alignment (GTK_MISC (label),
 				h_align(H_LEFT), v_align(V_CENTER));
+	gtk_misc_set_padding (GTK_MISC(label), GNOME_PAD_SMALL, 0);
 	gtk_container_add (GTK_CONTAINER (button), label);
 	generic_button_setup(button, should_dump);
 	bind_widget_info (button, w);
@@ -1080,12 +1081,14 @@ create_mainform(widget_info *w)
 
 		pane = gtk_hpaned_new ();
 		buttonbox = gtk_hbox_new (0, 0);
-		gtk_widget_set_usize(buttonbox, 400, 35);
+		gtk_widget_set_usize(buttonbox, 600, 35);
 
-		gtk_box_pack_start_defaults (GTK_BOX(vbox), pane);
-		gtk_box_pack_start_defaults (GTK_BOX(vbox), buttonbox);
+		gtk_box_pack_start (GTK_BOX(vbox), pane, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX(vbox), buttonbox, FALSE, FALSE, 0);
 
 		pagetop = gtk_notebook_new ();
+		gtk_notebook_set_scrollable (GTK_NOTEBOOK (pagetop), TRUE);
+		
 		treetop = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(treetop),
 						GTK_POLICY_AUTOMATIC,
